@@ -79,8 +79,17 @@ class Wimby:
                     else:
                         print(f"{fmovement} {token} ({change:,.2f}%)")
                     pattern = self.momentum.get(token, {}).get("trend", "")
+                    buy_score = self.momentum.get(token, {}).get("buy", 0) * 100
+                    sell_score = self.momentum.get(token, {}).get("sell", 0) * 100
+                    hold_score = max((buy_score, sell_score))
                     if pattern.strip() != "":
                         print(f"    {pattern}")
+                        if hold_score <= 60
+                            print(f"    HOLD: {sell_score:,.2f}%")
+                        elif buy_score > sell_score:
+                            print(f"    BUY:  {buy_score:,.2f}%")
+                        else:
+                            print(f"    SELL: {sell_score:,.2f}%")
             trend_avg = mean(market_trend)
             trend_mode = mode(market_trend)
             print("\n[Market Trends]")
@@ -143,11 +152,28 @@ def _historical_averages(coins, debug):
                         pattern.append("-")
                 else:
                     pattern.append(" ")
-                
+            
+            buy_score, sell_score = _scoring(pattern)
             trends.update({"trend": "".join(pattern)})
+            trends.update({"buy": buy_score})
+            trends.update({"sell": sell_score})
             momentum.set(token, trends)
     return momentum
 
+def _scoring(pattern):
+    buy_points = 0
+    sell_points = 0
+    for x in range(0, 7):
+        index = 7 - (x+1)
+        score = index+1
+        if pattern[index] == "+":
+            sell_points += score
+        else:
+            buy_points += score
+    buy_score = buy_points / 28
+    sell_score = sell_points / 28
+    return (buy_score, sell_score)
+
 def _prevailing(token):
     url = f"https://api.coingecko.com/api/v3/simple/price?ids={token}&vs_currencies=usd"
     return Arkivist().fetch(url)
